@@ -34,13 +34,6 @@ interface NodeRequire {
   (moduleName: 'electron/utility'): typeof Electron.Utility;
 }
 
-interface File {
-  /**
-   * The real path to the file on the users filesystem
-   */
-  path: string;
-}
-
 declare module 'original-fs' {
   import * as fs from 'fs';
   export = fs;
